@@ -50,6 +50,7 @@
 #' @param set_na specify whether NA values should be set for the NODATA
 #' @param band_output_type numeric type of band to apply (else the native type if ''), is mapped to one of 'Byte', 'Int32', or 'Float64'
 #' @param unscale default is `TRUE` so native values will be converted by offset and scale to floating point
+#' @param nara logical whether to return a (scaled) nativeRaster
 #' @export
 #' @return list of numeric vectors (only one for 'band')
 #' @examples
@@ -63,7 +64,7 @@
 #' ## the method can be used to up-sample as well
 #' str(matrix(vapour_read_raster(f, window = c(0, 0, 10, 10, 15, 25)), 15))
 #'
-vapour_read_raster <- function(x, band = 1, window, resample = "nearestneighbour", ..., sds = NULL, native = FALSE, set_na = TRUE, band_output_type = "", unscale = TRUE) {
+vapour_read_raster <- function(x, band = 1, window, resample = "nearestneighbour", ..., sds = NULL, native = FALSE, set_na = TRUE, band_output_type = "", unscale = TRUE, nara = FALSE) {
   x <- .check_dsn_single(x)
   if (!length(native) == 1L || is.na(native[1]) || !is.logical(native)) {
     stop("'native' must be a single 'TRUE' or 'FALSE'")
@@ -105,7 +106,7 @@ vapour_read_raster <- function(x, band = 1, window, resample = "nearestneighbour
   ## pull a swifty here with [[  to return numeric or integer
   ##vals <- raster_io_gdal_cpp(dsn = datasourcename, window  = window, band = band, resample = resample[1L], band_output_type = band_output_type)
   vals <- lapply(band, function(iband) {
-    raster_io_gdal_cpp(dsn = datasourcename, window  = window, band = iband, resample = resample[1L], band_output_type = band_output_type, unscale = unscale)[[1L]]
+    raster_io_gdal_cpp(dsn = datasourcename, window  = window, band = iband, resample = resample[1L], band_output_type = band_output_type, unscale = unscale, nara = nara)[[1L]]
   })
   if (set_na && !is.raw(vals[[1L]][1L])) {
     for (i in seq_along(vals)) {
@@ -134,9 +135,9 @@ vapour_read_raster <- function(x, band = 1, window, resample = "nearestneighbour
 vapour_read_raster_raw <- function(x, band = 1,
                                    window,
                                    resample = "nearestneighbour", ...,
-                                   sds = NULL, native = FALSE, set_na = TRUE) {
-  
+                                   sds = NULL, native = FALSE, set_na = TRUE, nara = FALSE) {
   
+  if (nara) message("nara incompatible with raw output, ignoring")
   if (length(band) > 1) message("_raw output implies one band, using only the first")
   vapour_read_raster(x, band = band, window = window, resample = resample, ..., sds = sds,
                      native = native, set_na = set_na, band_output_type = "Byte")[[1L]]
@@ -322,6 +323,7 @@ vapour_read_raster_hex <- function(x, band = 1,
 #' @param options character vectors of options as per the gdalwarp command line 
 #' @param nomd if `TRUE` the Metadata tag is removed from the resulting VRT (it can be quite substantial)
 #' @param overview pick an integer overview from the source (0L is highest resolution, default -1L does nothing)
+#' @param  nara if 'TRUE' return in nativeRaster format
 #' @export
 #' @seealso vapour_read_raster vapour_read_raster_raw vapour_read_raster_int vapour_read_raster_dbl vapour_read_raster_chr vapour_read_raster_hex
 #' @return list of vectors (only 1 for 'band') of numeric values, in raster order
@@ -352,7 +354,7 @@ vapour_warp_raster <- function(x, bands = NULL,
                                transformation_options = "", 
                                open_options = "",
                                options = "", 
-                               nomd = FALSE, overview = -1L) {
+                               nomd = FALSE, overview = -1L, nara = FALSE) {
   x <- .check_dsn_multiple(x)
   if (!is.null(bands) && (anyNA(bands) || length(bands) < 1 || !is.numeric(bands))) {
     stop("'bands' must be a valid set of band integers (1-based)")
@@ -381,9 +383,12 @@ vapour_warp_raster <- function(x, bands = NULL,
   
   ## bands
   if (is.numeric(bands) && any(bands < 1)) stop("all 'bands' index must be >= 1")
-  if (is.null(bands)) bands <- 0
-  if(length(bands) < 1 || anyNA(bands) || !is.numeric(bands)) stop("'bands' must be numeric (integer), start at 1")
-  bands <- as.integer(bands)
+  #if (is.null(bands)) bands <- 0
+
+  if (!is.null(bands)) {
+    if (length(bands) < 1 || anyNA(bands)) stop("'bands' must be numeric (integer), start at 1")
+    bands <- as.integer(bands)
+  }
   ##if ("projection" %in% names(list(...))) message("argument 'projection' input is ignored, warper functions use 'wkt = ' to specify target projection (any format is ok)")
   # dud_extent <- FALSE
   # if (is.null(extent)) {
@@ -411,9 +416,9 @@ vapour_warp_raster <- function(x, bands = NULL,
   
   ## if (dud_extent) extent <- 0.0
   ## hmm, we can't rely on gdalwarp to give a sensibleish dimension if not specified, it goes for the native-res
-  dud_dimension <- FALSE
+  #dud_dimension <- FALSE
   ## we dud it if no target projection is set, so you get native from the extent
-  if (is.null(dimension) && nchar(projection) < 1) {
+  if (!is.null(dimension)) {
     ## NO. We can't heuristic dimension or extent because we don't have a format to return those values with
     ##  we make a simple raster, the image() thing and go with that
     
@@ -427,14 +432,15 @@ vapour_warp_raster <- function(x, bands = NULL,
     ## ##  that has to be set in the C++, but we need to send down a message that the default is used (so do it all in C is the summ))
     ## set it to native with a max
     ## set it to native with a warn/override
-    dud_dimension <- TRUE
-    dimension <- c(2, 2)
+    #dud_dimension <- TRUE
+    #dimension <- c(2, 2)
+    if(!is.numeric(dimension)) stop("'dimension' must be numeric")
+    if(!length(dimension) == 2L) stop("'dimension must be of length 2'")
+    if(!all(dimension > 0)) stop("'dimension' values must be greater than 0")
+    if(!all(is.finite(dimension))) stop("'dimension' values must be finite and non-missing")
+    
   }
-  if(!is.numeric(dimension)) stop("'dimension' must be numeric")
-  if(!length(dimension) == 2L) stop("'dimension must be of length 2'")
-  if(!all(dimension > 0)) stop("'dimension' values must be greater than 0")
-  if(!all(is.finite(dimension))) stop("'dimension' values must be finite and non-missing")
-  if (dud_dimension) dimension <- 0
+  #if (dud_dimension) dimension <- 0
   
   
   if (length(source_extent) > 1) {
@@ -442,12 +448,14 @@ vapour_warp_raster <- function(x, bands = NULL,
       stop("'source_extent' must be numeric, of length 4 c(xmin, xmax, ymin, ymax)")
     }
     if (!all(is.finite(source_extent))) stop("'source_extent' values must be finite and non missing")
+    x <- vapour_vrt(x, source_extent = source_extent)
   }
   if(!is.null(source_projection)) {
     if (!is.character(source_projection)) stop("source_projection must be character")
     if(!silent) {
       if(!nchar(source_projection) > 10) message("short 'source_projection', possibly invalid?")
     }
+    x <- vapour_vrt(x, projection = source_projection)
   }
   
   if (!silent) {
@@ -507,16 +515,30 @@ vapour_warp_raster <- function(x, bands = NULL,
     stop("manually setting -r, -te, -t_srs, -of, -s_srs, -ot options not allowed \n ( these controlled by arguments 'resample', 'target_extent', 'target_projection', '<MEM>', 'source_projection', 'band_output_type')")
   } 
   if (any(grepl("-te_srs", options))) stop("setting '-te_srs' projection of target extent is not supported") 
-  vals <- warp_in_memory_gdal_cpp(x, source_WKT = source_projection,
-                                  target_WKT = projection,
-                                  target_extent = as.numeric(extent),
-                                  target_dim = as.integer(dimension),
-                                  bands = as.integer(bands),
-                                  source_extent = as.numeric(source_extent),
-                                  resample = resample,
-                                  silent = silent,
-                                  band_output_type = band_output_type, 
-                                  options = options, nomd = nomd, overview)
+
+  # vals <- warp_in_memory_gdal_cpp(x, source_WKT = source_projection,
+  #                                 target_WKT = projection,
+  #                                 target_extent = as.numeric(extent),
+  #                                 target_dim = as.integer(dimension),
+  #                                 bands = as.integer(bands),
+  #                                 source_extent = as.numeric(source_extent),
+  #                                 resample = resample,
+  #                                 silent = silent,
+  #                                 band_output_type = band_output_type, 
+  #                                 options = options, nomd = nomd, overview, nara = nara)
+  # 
+
+  if (nara) {
+    vals <- gdal_raster_nara(x, target_crs = projection, target_ext = extent, target_dim = dimension, 
+                             bands = bands, resample = resample, band_output_type = band_output_type, 
+                             options = options, include_meta = !nomd)
+  } else {
+  ## FIXME deal with nara and source projection source extent
+    if (is.null(bands)) bands <- 1L
+  vals <- gdal_raster_data(x, target_crs = projection, target_ext = extent, target_dim = dimension, 
+                           bands = bands, resample = resample, band_output_type = band_output_type, 
+                           options = options, include_meta = !nomd)
+  }
   # ##// if we Dataset->RasterIO we don't have separated bands'
   # nbands <- length(vals[[1L]]) / prod(as.integer(dimension))
   # if (nbands > 1) vals <- split(vals[[1L]], rep(seq_len(nbands), each = prod(as.integer(dimension))))
