@@ -19,7 +19,11 @@
 #' 
 #' `vapour_vrt()` is vectorized, it will return multiple VRT strings for multiple inputs in 
 #' a "length > 1" character vector. These are all independent, this is different to the function
-#' `vapour_warp_raster()` where multiple inputs are merged (possibly by sequential overlapping).  
+#' `vapour_warp_raster()` where multiple inputs are merged (possibly by sequential overlapping). 
+#' 
+#' If `geolocation` is set the 'GeoTransform' element is forcibly removed from the vrt output, in order
+#' to avoid https://github.com/hypertidy/vapour/issues/210 (there might be a better fix). 
+#' 
 #' @section Rationale:
 #' 
 #' For a raster, the basic essentials we can specify or modify for a source  are
@@ -58,7 +62,9 @@
 #' @param geolocation vector of 2 dsn to longitude, latitude geolocation array sources
 #' @return VRT character string (for use by GDAL-capable tools, i.e. reading raster)
 #' @param nomd if `TRUE` the Metadata tag is removed from the resulting VRT (it can be quite substantial)
+#' @param options pass in options to the VRT creation, like 'c("-expand", "rgb", "-ot", "Byte"('
 #' @param overview  pick an integer overview from the source (0L is highest resolution, default -1L does nothing)
+#'
 #' @export
 #'
 #' @examples
@@ -67,7 +73,8 @@
 #' 
 #' vapour_vrt(tif, bands = c(1, 1))
 #' 
-vapour_vrt <- function(x, extent = NULL, projection = NULL,  sds = 1L, bands = NULL, geolocation = NULL, ..., relative_to_vrt = FALSE, nomd = FALSE, overview = -1L) {
+vapour_vrt <- function(x, extent = NULL, projection = NULL,  sds = 1L, bands = NULL, geolocation = NULL, ..., 
+                       relative_to_vrt = FALSE, nomd = FALSE, overview = -1L, options = character()) {
   x <- .check_dsn_multiple_naok(x)
   
   if (!relative_to_vrt) { 
@@ -85,7 +92,6 @@ vapour_vrt <- function(x, extent = NULL, projection = NULL,  sds = 1L, bands = N
   if (is.na(sds[1]) || length(sds) > 1L || !is.numeric(sds) || sds < 1) {
     stop("'sds' must be a valid name or integer for a GDAL-subdataset (1-based)")
   }
-  
   ## FIXME: we can't do bands atm, also what else does boilerplate checks do that the new C++ in gdalraster doesn't do?
    # x <- sds_boilerplate_checks(x, sds)
    # if (!is.null(bands))  {
@@ -132,7 +138,118 @@ vapour_vrt <- function(x, extent = NULL, projection = NULL,  sds = 1L, bands = N
   overview <- as.integer(overview[1])
   if (is.na(overview)) overview <- -1L
 
-  raster_vrt_cpp(x, extent, projection[1L], sds, bands, geolocation, nomd, overview)
+  
+  # 
+  # CharacterVector dsn, 
+  # NumericVector extent, 
+  # CharacterVector projection, 
+  # IntegerVector sds, 
+  # IntegerVector bands, 
+  # CharacterVector geolocation, 
+  # LogicalVector nomd, 
+  # IntegerVector overview, 
+  # CharacterVector options
+  # 
+  # 
+  
+
+  out <- raster_vrt_cpp(x, extent, projection[1L], sds, bands, geolocation, nomd, overview, options)
+  ## scrub any transform, because of #210
+  if (nzchar(geolocation[1L])) {
+    out <- gsub("<GeoTransform.*GeoTransform>", "", out)
+  }
+  out
 }
 
+
+
+#' Vector VRT
+#'
+#' Just a simple text generator to generate the VRT for a vector layer, First layer is chosen if not
+#' otherwise specified. 
+#' 
+#' Using 'sql' overrides the 'layer', and using 'projection' results in the geometries being transformed. 
+#' No check is made of the layer source projection. 
+#' 
+#' Use 'a_srs' to ensure the source has a source crs (that might be the only thing you use this for, even if not reprojecting). 
+#' 
+#' It's expected that if you use this with a source without a source projection,
+#' you'll get "Failed to import source SRS", so use argument "a_srs" to set it
+#' if needed (or many other GDAL other facilities that do this).
+#' @param x data source name
+#' @param layer layer index (1-based) or name
+#' @param projection crs of the output
+#' @param sql SQL for ExecuteSQL to define the layer
+#' @param a_srs set the source crs
+#' @return single element character vector
+#' @export
+#'
+#' @examples
+#' file <- "list_locality_postcode_meander_valley.tab"
+#' ## A MapInfo TAB file with polygons
+#' mvfile <- system.file(file.path("extdata/tab", file), package="vapour")
+#' vector_vrt(mvfile, sql = "SELECT * FROM list_locality_postcode_meander_valley LIMIT 5 OFFSET 4")
+#' 
+#' ## read this with vapour_read_geometry() and it will be projected to VicGrid
+#' vector_vrt(mvfile, projection = "EPSG:3111")
+#' 
+vector_vrt <- function(x, layer = 1L, projection = NULL, sql = NULL, a_srs = NULL) {
+ 
+  if(!is.character(layer)) {
+    layer <- vapour::vapour_layer_names(x)[layer]
+  }
+  layer_srs <- ""
+  if (!is.null(a_srs)) {
+    layer_srs <- sprintf('<LayerSRS>%s</LayerSRS>', a_srs)
+  }
+  if (is.null(sql)) {
+    
+    
+    layer <- sprintf('<OGRVRTLayer name="%s">
+    <SrcDataSource>%s</SrcDataSource>
+    <SrcLayer>%s</SrcLayer> %s
+    </OGRVRTLayer>', layer, x, layer, layer_srs)
+  } else {
+    layer <- sprintf('<OGRVRTLayer name="%s">
+    <SrcDataSource>%s</SrcDataSource>
+    <SrcSQL>%s</SrcSQL> %s
+    </OGRVRTLayer>', layer, x, sql, layer_srs)
+  }
   
+  
+  if (file.exists(x)) {
+    x <- normalizePath(x)
+  }
+  
+  if (is.null(projection)) {
+    out <- sprintf('<OGRVRTDataSource>
+     %s
+ </OGRVRTDataSource>', layer)
+    
+  } else {
+    out <- sprintf('<OGRVRTDataSource>
+  <OGRVRTWarpedLayer>
+     %s
+    <TargetSRS>%s</TargetSRS>
+    </OGRVRTWarpedLayer>
+ </OGRVRTDataSource>', layer, projection)
+  }
+  out
+}
+
+
+#' Build vrt, special case "-separate"
+#'
+#' @param dsn one or more raster sources
+#'
+#' @return a character string of the built vrt, multiple sources treated as bands
+#' @export
+#'
+#' @examples
+#' f <- system.file("extdata/sst.tif", package = "vapour", mustWork = TRUE)
+#' vrt <- buildvrt(c(f, vapour_vrt(f)))
+#' writeLines(vrt)
+buildvrt <- function(dsn) {
+   options = c("-separate")
+   raster_buildvrt_cpp(dsn, options)
+ } 
