@@ -15,7 +15,9 @@ List warp_general_cpp(CharacterVector dsn,
                       LogicalVector silent,
                       CharacterVector band_output_type, 
                       CharacterVector options, 
-                      CharacterVector dsn_outname) {
+                      CharacterVector dsn_outname, 
+                      LogicalVector include_meta,
+                      LogicalVector nara) {
   return gdalwarpgeneral::gdal_warp_general(dsn,
                                           target_crs, 
                                           target_extent, 
@@ -26,7 +28,9 @@ List warp_general_cpp(CharacterVector dsn,
                                           silent, 
                                           band_output_type, 
                                           options, 
-                                          dsn_outname); 
+                                          dsn_outname, 
+                                          include_meta, 
+                                          nara); 
 }
 // [[Rcpp::export]]
 List warp_suggest_cpp(CharacterVector dsn, CharacterVector target_crs) {
